package androidx.core.graphics.drawable;

import android.content.Context;
import android.content.res.ColorStateList;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.Shader;
import android.graphics.drawable.AdaptiveIconDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.Icon;
import android.net.Uri;
import android.os.Build;
import android.os.Parcelable;
import android.text.TextUtils;
import android.util.Log;
import androidx.versionedparcelable.CustomVersionedParcelable;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import java.nio.charset.Charset;

public class IconCompat extends CustomVersionedParcelable {

    /* renamed from: ˎ  reason: contains not printable characters */
    static final PorterDuff.Mode f1729 = PorterDuff.Mode.SRC_IN;

    /* renamed from: ʻ  reason: contains not printable characters */
    public int f1730 = -1;

    /* renamed from: ʼ  reason: contains not printable characters */
    Object f1731;

    /* renamed from: ʽ  reason: contains not printable characters */
    public byte[] f1732 = null;

    /* renamed from: ʾ  reason: contains not printable characters */
    public Parcelable f1733 = null;

    /* renamed from: ʿ  reason: contains not printable characters */
    public int f1734 = 0;

    /* renamed from: ˆ  reason: contains not printable characters */
    public int f1735 = 0;

    /* renamed from: ˈ  reason: contains not printable characters */
    public ColorStateList f1736 = null;

    /* renamed from: ˉ  reason: contains not printable characters */
    PorterDuff.Mode f1737 = f1729;

    /* renamed from: ˊ  reason: contains not printable characters */
    public String f1738 = null;

    /* renamed from: ˋ  reason: contains not printable characters */
    public String f1739;

    static class b {
        /* renamed from: ʻ  reason: contains not printable characters */
        static Drawable m1967(Drawable drawable, Drawable drawable2) {
            return new AdaptiveIconDrawable(drawable, drawable2);
        }

        /* renamed from: ʻ  reason: contains not printable characters */
        static Icon m1968(Bitmap bitmap) {
            return Icon.createWithAdaptiveBitmap(bitmap);
        }
    }

    /* access modifiers changed from: package-private */
    public static class c {
        /* renamed from: ʻ  reason: contains not printable characters */
        static int m1969(Object obj) {
            return ((Icon) obj).getResId();
        }

        /* renamed from: ʼ  reason: contains not printable characters */
        static String m1970(Object obj) {
            return ((Icon) obj).getResPackage();
        }

        /* renamed from: ʽ  reason: contains not printable characters */
        static int m1971(Object obj) {
            return ((Icon) obj).getType();
        }

        /* renamed from: ʾ  reason: contains not printable characters */
        static Uri m1972(Object obj) {
            return ((Icon) obj).getUri();
        }
    }

    static class d {
        /* renamed from: ʻ  reason: contains not printable characters */
        static Icon m1973(Uri uri) {
            return Icon.createWithAdaptiveBitmapContentUri(uri);
        }
    }

    /* renamed from: ʻ  reason: contains not printable characters */
    private static String m1955(int i) {
        switch (i) {
            case 1:
                return "BITMAP";
            case 2:
                return "RESOURCE";
            case 3:
                return "DATA";
            case 4:
                return "URI";
            case 5:
                return "BITMAP_MASKABLE";
            case 6:
                return "URI_MASKABLE";
            default:
                return "UNKNOWN";
        }
    }

    public String toString() {
        if (this.f1730 == -1) {
            return String.valueOf(this.f1731);
        }
        StringBuilder sb = new StringBuilder("Icon(typ=");
        sb.append(m1955(this.f1730));
        switch (this.f1730) {
            case 1:
            case 5:
                sb.append(" size=");
                sb.append(((Bitmap) this.f1731).getWidth());
                sb.append("x");
                sb.append(((Bitmap) this.f1731).getHeight());
                break;
            case 2:
                sb.append(" pkg=");
                sb.append(this.f1739);
                sb.append(" id=");
                sb.append(String.format("0x%08x", Integer.valueOf(m1956())));
                break;
            case 3:
                sb.append(" len=");
                sb.append(this.f1734);
                if (this.f1735 != 0) {
                    sb.append(" off=");
                    sb.append(this.f1735);
                    break;
                }
                break;
            case 4:
            case 6:
                sb.append(" uri=");
                sb.append(this.f1731);
                break;
        }
        if (this.f1736 != null) {
            sb.append(" tint=");
            sb.append(this.f1736);
        }
        if (this.f1737 != f1729) {
            sb.append(" mode=");
            sb.append(this.f1737);
        }
        sb.append(")");
        return sb.toString();
    }

    /* renamed from: ʻ  reason: contains not printable characters */
    public int m1956() {
        if (this.f1730 == -1 && Build.VERSION.SDK_INT >= 23) {
            return a.m1962(this.f1731);
        }
        if (this.f1730 == 2) {
            return this.f1734;
        }
        throw new IllegalStateException("called getResId() on " + this);
    }

    /* renamed from: ʼ  reason: contains not printable characters */
    public String m1959() {
        if (this.f1730 == -1 && Build.VERSION.SDK_INT >= 23) {
            return a.m1965(this.f1731);
        }
        if (this.f1730 == 2) {
            String str = this.f1739;
            if (str == null || TextUtils.isEmpty(str)) {
                return ((String) this.f1731).split(":", -1)[0];
            }
            return this.f1739;
        }
        throw new IllegalStateException("called getResPackage() on " + this);
    }

    /* renamed from: ʽ  reason: contains not printable characters */
    public Uri m1960() {
        if (this.f1730 == -1 && Build.VERSION.SDK_INT >= 23) {
            return a.m1966(this.f1731);
        }
        int i = this.f1730;
        if (i == 4 || i == 6) {
            return Uri.parse((String) this.f1731);
        }
        throw new IllegalStateException("called getUri() on " + this);
    }

    /* renamed from: ʾ  reason: contains not printable characters */
    public void m1961() {
        this.f1737 = PorterDuff.Mode.valueOf(this.f1738);
        switch (this.f1730) {
            case -1:
                Parcelable parcelable = this.f1733;
                if (parcelable != null) {
                    this.f1731 = parcelable;
                    return;
                }
                throw new IllegalArgumentException("Invalid icon");
            case 0:
            default:
                return;
            case 1:
            case 5:
                Parcelable parcelable2 = this.f1733;
                if (parcelable2 != null) {
                    this.f1731 = parcelable2;
                    return;
                }
                byte[] bArr = this.f1732;
                this.f1731 = bArr;
                this.f1730 = 3;
                this.f1734 = 0;
                this.f1735 = bArr.length;
                return;
            case 2:
            case 4:
            case 6:
                String str = new String(this.f1732, Charset.forName("UTF-16"));
                this.f1731 = str;
                if (this.f1730 == 2 && this.f1739 == null) {
                    this.f1739 = str.split(":", -1)[0];
                    return;
                }
                return;
            case 3:
                this.f1731 = this.f1732;
                return;
        }
    }

    /* access modifiers changed from: package-private */
    public static class a {
        /* renamed from: ʻ  reason: contains not printable characters */
        static int m1962(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.m1969(obj);
            }
            try {
                return ((Integer) obj.getClass().getMethod("getResId", new Class[0]).invoke(obj, new Object[0])).intValue();
            } catch (IllegalAccessException e2) {
                Log.e("IconCompat", "Unable to get icon resource", e2);
                return 0;
            } catch (InvocationTargetException e3) {
                Log.e("IconCompat", "Unable to get icon resource", e3);
                return 0;
            } catch (NoSuchMethodException e4) {
                Log.e("IconCompat", "Unable to get icon resource", e4);
                return 0;
            }
        }

        /* renamed from: ʼ  reason: contains not printable characters */
        static String m1965(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.m1970(obj);
            }
            try {
                return (String) obj.getClass().getMethod("getResPackage", new Class[0]).invoke(obj, new Object[0]);
            } catch (IllegalAccessException e2) {
                Log.e("IconCompat", "Unable to get icon package", e2);
                return null;
            } catch (InvocationTargetException e3) {
                Log.e("IconCompat", "Unable to get icon package", e3);
                return null;
            } catch (NoSuchMethodException e4) {
                Log.e("IconCompat", "Unable to get icon package", e4);
                return null;
            }
        }

        /* renamed from: ʽ  reason: contains not printable characters */
        static Uri m1966(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.m1972(obj);
            }
            try {
                return (Uri) obj.getClass().getMethod("getUri", new Class[0]).invoke(obj, new Object[0]);
            } catch (IllegalAccessException e2) {
                Log.e("IconCompat", "Unable to get icon uri", e2);
                return null;
            } catch (InvocationTargetException e3) {
                Log.e("IconCompat", "Unable to get icon uri", e3);
                return null;
            } catch (NoSuchMethodException e4) {
                Log.e("IconCompat", "Unable to get icon uri", e4);
                return null;
            }
        }

        /* renamed from: ʻ  reason: contains not printable characters */
        static Icon m1964(IconCompat iconCompat, Context context) {
            Icon icon;
            switch (iconCompat.f1730) {
                case -1:
                    return (Icon) iconCompat.f1731;
                case 0:
                default:
                    throw new IllegalArgumentException("Unknown type");
                case 1:
                    icon = Icon.createWithBitmap((Bitmap) iconCompat.f1731);
                    break;
                case 2:
                    icon = Icon.createWithResource(iconCompat.m1959(), iconCompat.f1734);
                    break;
                case 3:
                    icon = Icon.createWithData((byte[]) iconCompat.f1731, iconCompat.f1734, iconCompat.f1735);
                    break;
                case 4:
                    icon = Icon.createWithContentUri((String) iconCompat.f1731);
                    break;
                case 5:
                    if (Build.VERSION.SDK_INT < 26) {
                        icon = Icon.createWithBitmap(IconCompat.m1954((Bitmap) iconCompat.f1731, false));
                        break;
                    } else {
                        icon = b.m1968((Bitmap) iconCompat.f1731);
                        break;
                    }
                case 6:
                    if (Build.VERSION.SDK_INT >= 30) {
                        icon = d.m1973(iconCompat.m1960());
                        break;
                    } else if (context != null) {
                        InputStream r5 = iconCompat.m1957(context);
                        if (r5 != null) {
                            if (Build.VERSION.SDK_INT < 26) {
                                icon = Icon.createWithBitmap(IconCompat.m1954(BitmapFactory.decodeStream(r5), false));
                                break;
                            } else {
                                icon = b.m1968(BitmapFactory.decodeStream(r5));
                                break;
                            }
                        } else {
                            throw new IllegalStateException("Cannot load adaptive icon from uri: " + iconCompat.m1960());
                        }
                    } else {
                        throw new IllegalArgumentException("Context is required to resolve the file uri of the icon: " + iconCompat.m1960());
                    }
            }
            ColorStateList colorStateList = iconCompat.f1736;
            if (colorStateList != null) {
                icon.setTintList(colorStateList);
            }
            PorterDuff.Mode mode = iconCompat.f1737;
            if (mode != IconCompat.f1729) {
                icon.setTintMode(mode);
            }
            return icon;
        }

        /* renamed from: ʻ  reason: contains not printable characters */
        static Drawable m1963(Icon icon, Context context) {
            return icon.loadDrawable(context);
        }
    }

    /* renamed from: ʻ  reason: contains not printable characters */
    public InputStream m1957(Context context) {
        Uri r0 = m1960();
        String scheme = r0.getScheme();
        if ("content".equals(scheme) || "file".equals(scheme)) {
            try {
                return context.getContentResolver().openInputStream(r0);
            } catch (Exception e2) {
                Log.w("IconCompat", "Unable to load image from URI: " + r0, e2);
                return null;
            }
        } else {
            try {
                return new FileInputStream(new File((String) this.f1731));
            } catch (FileNotFoundException e3) {
                Log.w("IconCompat", "Unable to load image from path: " + r0, e3);
                return null;
            }
        }
    }

    /* renamed from: ʻ  reason: contains not printable characters */
    public void m1958(boolean z) {
        this.f1738 = this.f1737.name();
        switch (this.f1730) {
            case -1:
                if (!z) {
                    this.f1733 = (Parcelable) this.f1731;
                    return;
                }
                throw new IllegalArgumentException("Can't serialize Icon created with IconCompat#createFromIcon");
            case 0:
            default:
                return;
            case 1:
            case 5:
                if (z) {
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    ((Bitmap) this.f1731).compress(Bitmap.CompressFormat.PNG, 90, byteArrayOutputStream);
                    this.f1732 = byteArrayOutputStream.toByteArray();
                    return;
                }
                this.f1733 = (Parcelable) this.f1731;
                return;
            case 2:
                this.f1732 = ((String) this.f1731).getBytes(Charset.forName("UTF-16"));
                return;
            case 3:
                this.f1732 = (byte[]) this.f1731;
                return;
            case 4:
            case 6:
                this.f1732 = this.f1731.toString().getBytes(Charset.forName("UTF-16"));
                return;
        }
    }

    /* renamed from: ʻ  reason: contains not printable characters */
    static Bitmap m1954(Bitmap bitmap, boolean z) {
        int min = (int) (((float) Math.min(bitmap.getWidth(), bitmap.getHeight())) * 0.6666667f);
        Bitmap createBitmap = Bitmap.createBitmap(min, min, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        Paint paint = new Paint(3);
        float f2 = (float) min;
        float f3 = 0.5f * f2;
        float f4 = 0.9166667f * f3;
        if (z) {
            float f5 = 0.010416667f * f2;
            paint.setColor(0);
            paint.setShadowLayer(f5, 0.0f, f2 * 0.020833334f, 1023410176);
            canvas.drawCircle(f3, f3, f4, paint);
            paint.setShadowLayer(f5, 0.0f, 0.0f, 503316480);
            canvas.drawCircle(f3, f3, f4, paint);
            paint.clearShadowLayer();
        }
        paint.setColor(-16777216);
        Shader.TileMode tileMode = Shader.TileMode.CLAMP;
        BitmapShader bitmapShader = new BitmapShader(bitmap, tileMode, tileMode);
        Matrix matrix = new Matrix();
        matrix.setTranslate(((float) (-(bitmap.getWidth() - min))) / 2.0f, ((float) (-(bitmap.getHeight() - min))) / 2.0f);
        bitmapShader.setLocalMatrix(matrix);
        paint.setShader(bitmapShader);
        canvas.drawCircle(f3, f3, f4, paint);
        canvas.setBitmap(null);
        return createBitmap;
    }
}
